@@ -351,8 +351,13 @@ class DobissTempSensor(DobissSensor):
         value = round((value - 5)*10)
         await self._dobiss.action(self._address, self._channel, 1, value)
 
-    async def set_hvac_mode(self, hvac_mode: str):
-        logger.info("todo, set havc mode")
+    async def set_manual_mode(self, manual = True):
+        if manual:
+            args = {}
+            args["temperature"] = self.asked
+            await self.set_temperature(**args)
+        else:
+            await self._dobiss.action(self._address, self._channel, 0)
 
     async def set_preset_mode(self, preset_mode: str):
         id = None
